==> nextcloud-20.0.14.tgz: nextcloud/apps/dashboard/l10n/es.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "App Dashboard",
    "Show something" : "Mostrar algo",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the App Store" : "Conseguir más widgets desde la tienda de Apps",
    "Change background image" : "Cambiar imagen de fondo",
    "Weather service" : "Servicio metereológico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Por privacidad, los datos meteorológicos son solicitados por tu servidor Nextcloud en tu nombre de tal forma que el servicio no recibe información personal.",
    "Weather data from Met.no" : "Datos meteorológicos de Met.no",
    "geocoding with Nominatim" : "geocoding con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "El tiempo",
    "Status" : "Estado",
    "Good morning" : "Buenos días",
    "Good morning, {name}" : "Buenos días, {name}",
    "Good afternoon" : "Buenas tardes",
    "Good afternoon, {name}" : "Buenas tardes, {name}",
    "Good evening" : "Buenas tardes",
    "Good evening, {name}" : "Buenas tardes, {name}",
    "Hello" : "Hola",
    "Hello, {name}" : "Hola, {name}",
    "Pick from Files" : "Elegir de Archivos",
    "Default images" : "Imágenes predeterminadas",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}",
    "Get more widgets from the app store" : "Conseguir más widgets desde la app store",
    "Good night, {name}" : "Buenas noches, {name}",
    "Good night" : "Buenas noches",
    "Pick from files" : "Escoger desde los archivos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.8.tgz: nextcloud/apps/dashboard/l10n/es.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "App Dashboard",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Comienza tu día informado\n\nEl Dashboard de Nextcloud es tu punto de partida del día, dándote un\nresumen de tus próximas citas, emails urgentes, mensajes de chat,\npróximos tickets, últimos tweets y mucho más! Los usuarios pueden agregr widgets\nque le gusten y cambiar el fondo a su gusto.",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the App Store" : "Conseguir más widgets desde la tienda de Apps",
    "Change background image" : "Cambiar imagen de fondo",
    "Weather service" : "Servicio metereológico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Por privacidad, los datos meteorológicos son solicitados por tu servidor Nextcloud en tu nombre de tal forma que el servicio no recibe información personal.",
    "Weather data from Met.no" : "Datos meteorológicos de Met.no",
    "geocoding with Nominatim" : "geocoding con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "El tiempo",
    "Status" : "Estado",
    "Good morning" : "Buenos días",
    "Good morning, {name}" : "Buenos días, {name}",
    "Good afternoon" : "Buenas tardes",
    "Good afternoon, {name}" : "Buenas tardes, {name}",
    "Good evening" : "Buenas tardes",
    "Good evening, {name}" : "Buenas tardes, {name}",
    "Hello" : "Hola",
    "Hello, {name}" : "Hola, {name}",
    "Pick from Files" : "Elegir de Archivos",
    "Default images" : "Imágenes predeterminadas",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}",
    "Show something" : "Mostrar algo"
},
"nplurals=2; plural=(n != 1);");
